using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using C1.C1Preview;

namespace C1SampleViewer
{
    public class C1SampleOptions : C1PrintDocument
    {
        public void LoadFromSettings()
        {
            // Clear existing contents
            this.Clear();

            // Create a document title
            RenderText text = new RenderText("C1SampleViewer Options");
            text.Style.Font = new Font("Trebuchet MS", 16, FontStyle.Bold);
            text.Style.Spacing.Bottom = "20pt";
            this.Body.Children.Add(text);

            // Create instructions for use
            text = new RenderText("Instructions go here.");
            text.Style.Font = new Font("Trebuchet MS", 10);
            text.Style.Spacing.Bottom = "10pt";
            //this.Body.Children.Add(text);

            // Create a new user action to handle mouse clicks. Re-use the built-in
            // reflow handler since no additional event arguments are required.
            InputAction act = new InputAction();
            act.UserAction = UserActionEnum.Click;
            act.ActionHandler = new ActionHandlerReflow();

            bool local = C1SampleViewer.Properties.Settings.Default.Local;
            bool toc = C1SampleViewer.Properties.Settings.Default.Toc;
            bool index = C1SampleViewer.Properties.Settings.Default.Index;
            string path = C1SampleViewer.Properties.Settings.Default.LocalPath;

            RenderText label1 = new RenderText();
            label1.Style.Font = new Font("Trebuchet MS", 12, FontStyle.Bold);
            label1.Style.BackColor = Color.Crimson;
            label1.Style.TextColor = Color.White;
            label1.Style.Padding.All = "4pt";
            label1.Style.Spacing.Top = "0.25in";
            label1.Text = "Load samples from";

            RenderInputRadioButton ilocal = new RenderInputRadioButton(this);
            ilocal.Width = "2in";
            ilocal.Height = "0.25in";
            ilocal.Style.Font = new Font("Trebuchet MS", 10);
            ilocal.Style.Padding.Top = "2pt";
            ilocal.Text = "Local machine";
            ilocal.Checked = local;

            RenderInputText ipath = new RenderInputText(this);
            ipath.Width = "4in";
            ipath.Height = "0.25in";
            ipath.Style.Font = new Font("Trebuchet MS", 10);
            ipath.Style.Padding.Left = "13.5pt";
            ipath.Text = path;

            RenderInputRadioButton iremote = new RenderInputRadioButton(this);
            iremote.Width = "2in";
            iremote.Height = "0.25in";
            iremote.Style.Font = new Font("Trebuchet MS", 10);
            iremote.Text = "HelpCentral site";
            iremote.Checked = !local;

            RenderText label2 = new RenderText();
            label2.Style.Font = new Font("Trebuchet MS", 12, FontStyle.Bold);
            label2.Style.BackColor = Color.Crimson;
            label2.Style.TextColor = Color.White;
            label2.Style.Padding.All = "4pt";
            label2.Style.Spacing.Top = "0.25in";
            label2.Text = "Document options";

            RenderInputCheckBox itoc = new RenderInputCheckBox(this);
            itoc.Width = "2in";
            itoc.Height = "0.25in";
            itoc.Style.Font = new Font("Trebuchet MS", 10);
            itoc.Style.Padding.Top = "2pt";
            itoc.Text = "Table of Contents";
            itoc.Checked = toc;

            RenderInputCheckBox iindex = new RenderInputCheckBox(this);
            iindex.Width = "2in";
            iindex.Height = "0.25in";
            iindex.Style.Font = new Font("Trebuchet MS", 10);
            iindex.Text = "Index";
            iindex.Checked = index;

            // Create an input button and attach it to the action handler
            RenderInputButton ibtn = new RenderInputButton(this, "OK");
            ibtn.Width = "4in";
            ibtn.Height = "0.5in";
            ibtn.Style.Font = new Font("Trebuchet MS", 8, FontStyle.Bold);
            ibtn.Style.Spacing.Top = "0.25in";
            ibtn.Style.Spacing.Left = "3in";
            ibtn.InputActions.Add(act);
            ibtn.AcceptButton = true;

            // Force the preview form to accept the input button
            this.FormsKeyActionEnter = FormsKeyActionEnterEnum.InvokeAcceptButton;

            // Create a table to hold the input controls
            RenderTable table = new RenderTable(8, 1);
            table.Cells[0, 0].Area.Children.Add(label1);
            table.Cells[1, 0].Area.Children.Add(ilocal);
            table.Cells[2, 0].Area.Children.Add(ipath);
            table.Cells[3, 0].Area.Children.Add(iremote);
            table.Cells[4, 0].Area.Children.Add(label2);
            table.Cells[5, 0].Area.Children.Add(itoc);
            table.Cells[6, 0].Area.Children.Add(iindex);
            table.Cells[7, 0].Area.Children.Add(ibtn);
            this.Body.Children.Add(table);
            table.Width = "4in";

            // Change the document title and generate it
            this.DocumentInfo.Title = "Options";
            this.Generate();
        }

        public void SaveToSettings(RenderObject ro)
        {
            // Derive the input control container from the item that was clicked
            RenderTable table = ro.Parent.Parent as RenderTable;
            
            // Get individual input controls from the table
            RenderInputRadioButton ilocal = table.Cells[1, 0].Area.Children[0] as RenderInputRadioButton;
            RenderInputCheckBox itoc = table.Cells[5, 0].Area.Children[0] as RenderInputCheckBox;
            RenderInputCheckBox iindex = table.Cells[6, 0].Area.Children[0] as RenderInputCheckBox;
            RenderInputText ipath = table.Cells[2, 0].Area.Children[0] as RenderInputText;

            // Save the updated user settings values
            C1SampleViewer.Properties.Settings.Default.LocalPath = ipath.Text;
            C1SampleViewer.Properties.Settings.Default.Local = ilocal.Checked;
            C1SampleViewer.Properties.Settings.Default.Toc = itoc.Checked;
            C1SampleViewer.Properties.Settings.Default.Index = iindex.Checked;
            C1SampleViewer.Properties.Settings.Default.Save();
        }
    }
}
