using System;
using System.Text;
using System.IO;

namespace C1SampleViewer
{
	public sealed class VSLauncher
	{
		public static readonly VSLauncher Instance = new VSLauncher();

		private string vs2002 = null;
		private string vs2003 = null;
		private string vs2005 = null;

		private bool vs2002Exists = false;
		private bool vs2003Exists = false;
		private bool vs2005Exists = false;
		private bool vsAnyExists = false;

		private VSLauncher()
		{
			vs2002 = GetVersion("VSCOMNTOOLS");
			vs2003 = GetVersion("VS71COMNTOOLS");
			vs2005 = GetVersion("VS80COMNTOOLS");

			if (vs2002 != null)
				vs2002Exists = File.Exists(vs2002);

			if (vs2003 != null)
				vs2003Exists = File.Exists(vs2003);

			if (vs2005 != null)
				vs2005Exists = File.Exists(vs2005);

			vsAnyExists = vs2002Exists || vs2003Exists || vs2005Exists;
		}

		private string GetVersion(string env)
		{
			string devenv = Environment.GetEnvironmentVariable(env);
			
			if (devenv != null && devenv.EndsWith("Tools\\"))
			{
				devenv = devenv.Substring(0, devenv.Length - 6);
				devenv += "IDE\\devenv.exe";
			}
			else
			{
				devenv = null;
			}

			return devenv;
		}

		public string GetProgram(string path)
		{
			if (!vsAnyExists || !File.Exists(path))
				return path;

			string[] lines = File.ReadAllLines(path);

			for (int i = 0; i < lines.Length; i++)
			{
				string s = lines[i];

				if (s.Contains("Version"))
				{
					if (s.Contains("7.0"))
					{
						if (vs2002Exists) return vs2002;
						if (vs2003Exists) return vs2003;
						if (vs2005Exists) return vs2005;
					}

					else if (s.Contains("8.00") || s.Contains("7.10"))
					{
						if (vs2003Exists) return vs2003;
						if (vs2005Exists) return vs2005;
					}

					else if (s.Contains("9.00") || s.Contains("<ProductVersion>"))
					{
						if (vs2005Exists) return vs2005;
					}
				}
			}

            return path;
		}
	}
}
